airwatch-sdk-plugin
===================

This plugin provides Cordova access to features of the AirWatch mobile device management SDK for iOS and Android.

Installation
------------

Installation of the plugin is straightforward; simply type `cordova plugin add airwatch-sdk-plugin` at the command line.

Initialization
--------------

The plugin will auto-start on both Android and iOS devices, and will automatically start the AirWatch SDK. After startup, the functions will be available in the `plugins.airwatch` property of the `window` object. No other initialization is required to use the functions documented below.

To receive events from the SDK, an event listener must be initialized. See "Events" below.

Functions
---------
<dl>

<dt>setSDKEventListener(listener)</dt>
<dd>Set an event-handler function to receive events from the SDK. See "Events" below.</dd>

<dt>username(successCallback, errorCallback)</dt>
<dd>Get the enrolled user's username. The username will be returned as a string parameter to the successCallback function.</dd>

<dt>groupId(successCallback, errorCallback)</dt>
<dd>Get the enrolled user's group ID. The group ID will be returned as a string parameter to the successCallback function.</dd>

<dt>serverName(successCallback, errorCallback)</dt>
<dd>Get the name of the server to which the device is enrolled. The server name will be returned as a string parameter to the successCallback function.</dd>

<dt>allowCopyPaste(successCallback, errorCallback)</dt>
<dd>Gets the "allow copy/paste" setting for the profile: true if the user is allowed to copy and paste between managed apps, false otherwise. The value will be returned as a boolean parameter to the successCallback function.</dd>

<dt>allowOffline(successCallback, errorCallback)</dt>
<dd>Gets the "allow offline use" setting for the profile: true if the user is allowed to use managed apps when not connected to the network, false otherwise. The value will be returned as a boolean parameter to the successCallback function.</dd>

<dt>customSettings(successCallback, errorCallback)</dt>
<dd>Gets any custom settings provided in the app's profile. The value will be returned as a string parameter to the successCallback function.</dd>

</dl>

Events
------
The AirWatch SDK sends event notifications to applications that use it when certain conditions arise. To receive these notifications in a Cordova app, the developer must first call `setSDKEventListener(listener)`, where `listener` is a function that accepts two parameters. The first parameter will be a string containing the name of the event, as listed below. The second will be an Object that will contain additional data if relevant to that type of event.

<dl>

<dt><code>wipe</code></dt>
<dd>Sent when the device receives a "wipe" instruction from the console.</dd>

<dt><code>lock</code></dt>
<dd>Sent when the device receives a "lock" instruction from the console.</dd>

<dt><code>unlock</code></dt>
<dd>Sent when the device receives an "unlock" instruction from the console.</dd>

<dt><code>stopNetworkActivity</code></dt>
<dd>Sent when the device receives a "stopNetworkActivity" instruction from the console. The event data parameter contains a property named <code>status</code> with a numeric value as specified in the table below.</dd>

<dt><code>resumeNetworkActivity</code></dt>
<dd>Sent when the device receives a "resumeNetworkActivity" instruction from the console.</dd>

</dl>

### Network status values for `stopNetworkActivity`:

Status code | Network state
:----------:|:-------------
 -2         | initializing
 -1         | normal
  0         | bad SSID
  1         | cellular data disabled
  2         | roaming
  3         | proxy failed
  4         | network not reachable


